#[non_exhaustive]pub struct MarkdownOptions {
pub title: Option<String>,
pub heading_level: u8,
pub include_table_of_contents: bool,
pub include_rust_types: bool,
pub include_aliases: bool,
pub include_env_vars: Option<EnvVarOptions>,
pub include_examples: bool,
pub include_secret_marker: bool,
}Expand description
Options controlling Markdown reference generation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>Optional top-level title to emit before the generated reference.
heading_level: u8Markdown heading level for Self::title. Nested headings are derived from this level.
include_table_of_contents: boolWhether to include a generated table of contents.
include_rust_types: boolWhether to include Rust type names in the generated reference.
include_aliases: boolWhether to include config and param aliases.
include_env_vars: Option<EnvVarOptions>Whether to include environment variable names for canonical param paths.
include_examples: boolWhether to include example values.
include_secret_marker: boolWhether to mark secret params and child values.